import React, { useEffect, useRef, useState } from "react";
import {
  createStackNavigator,
  TransitionPresets,
} from "@react-navigation/stack";
import Apps from "./components/Apps";
import TrainBase from "./components/trainbaseview";
import HowTo from "./howto";
import News from "./components/news";
import TrainMenu from "./components/trainMenu";
import FavoriteList from "./components/FavoriteList";
import { optionData } from "./lib/stackOption";
import { useNavigation } from "@react-navigation/native";
import { useCurrentTrain } from "./stateBox/useCurrentTrain";
import { useTrainMenu } from "./stateBox/useTrainMenu";
import { AS } from "./storageControl";
import { news } from "./config/newsUpdate";
const Stack = createStackNavigator();
export const Top = ({ navigationRef }) => {
  const { webview } = useCurrentTrain();
  const { navigate, addListener } = useNavigation();


  useEffect(() => {
    //ニュース表示
    AS.getItem("status")
      .then((d) => {
        if (d != news) navigate("news");
      })
      .catch(() => navigate("news"));
  }, []);



  //地図用
  const { injectJavaScript, setInjectJavaScript, mapSwitch } = useTrainMenu();

  const goToFavoriteList = () => navigate("favoriteList");

  useEffect(() => {
    const unsubscribe = addListener("tabLongPress", goToFavoriteList);
    return unsubscribe;
  }, [{ navigate, addListener }]);

  const goToTrainMenu = () => {
    if (navigationRef.current?.getCurrentRoute().name == "Apps") {
      if (mapSwitch == "true") {
        navigate("trainMenu");
        setInjectJavaScript("");
      } else {
        webview.current?.injectJavaScript(`AccordionClassEvent()`);
      }
    } else {
      if (mapSwitch == "true") {
        if (injectJavaScript) {
          webview.current?.injectJavaScript(injectJavaScript);
          setInjectJavaScript("");
        }
      }
      navigate("Apps");
    }
  };
  useEffect(() => {
    const unsubscribe = addListener("tabPress", goToTrainMenu);
    return unsubscribe;
  }, [{ navigate, addListener }, mapSwitch, injectJavaScript]);

  return (
    <Stack.Navigator>
      <Stack.Screen
        name="Apps"
        options={{
          headerShown: false,
          gestureEnabled: true,
          headerTransparent: true,
        }}
        component={Apps}
      />
      <Stack.Screen
        name="trainbase"
        options={{
          title: "トレインビジョン",
          gestureEnabled: true,
          ...TransitionPresets.SlideFromRightIOS,
        }}
        component={TrainBase}
      />

      <Stack.Screen name="howto" options={optionData} component={HowTo} />
      <Stack.Screen name="news" options={optionData} component={News} />

      <Stack.Screen
        name="trainMenu"
        options={optionData}
        component={TrainMenu}
      />

      <Stack.Screen
        name="favoriteList"
        options={{ ...optionData, gestureEnabled: false }}
        component={FavoriteList}
      />
    </Stack.Navigator>
  );
};
